# Report Filename Versioning Guide

このガイドはセクションごとに再編されました。以下のドキュメントを参照してください。

- [index.md](report_filename_versioning/index.md) — 全体概要
- [basics.md](report_filename_versioning/basics.md) — 基本フォーマットと Version パラメータ
- [use_cases.md](report_filename_versioning/use_cases.md) — 代表的ユースケース
- [naming.md](report_filename_versioning/naming.md) — 命名規約とベストプラクティス
- [integration.md](report_filename_versioning/integration.md) — 統合例・テスト・API
- [faq.md](report_filename_versioning/faq.md) — FAQ と参考資料

> 既存リンクは上記セクションに更新してください。内容自体は変更しておらず、読みやすさのため分割しています。
